@@ -55,6 +55,11 @@ void prog_init(char **file)
 
 	msgbox_create();
 
+	doc_pointer_to_int = g_hash_table_new (g_direct_hash, g_direct_equal);
+	doc_int_to_pointer = g_hash_table_new (g_direct_hash, g_direct_equal);
+	win_pointer_to_int = g_hash_table_new (g_direct_hash, g_direct_equal);
+	win_int_to_pointer = g_hash_table_new (g_direct_hash, g_direct_equal);
+
 	window_list = NULL;
 	window = gE_window_new();
 	data->window = window;
