@@ -30,7 +30,6 @@
 #include "gE_document.h"
 #include "gE_prefs.h"
 #include "gE_plugin_api.h"
-#include "menus.h"
 #include "msgbox.h"
 
 GList *window_list;
@@ -85,7 +84,6 @@ main (int argc, char **argv)
 	signal(SIGTERM, SIG_DFL);
 #endif
 
-	gE_get_rc_file();
 	gE_rc_parse();
 
 	prog_init(argv + 1);
@@ -162,6 +160,11 @@ int main (int argc, char **argv)
 
 	gE_rc_parse();
 
+	doc_pointer_to_int = g_hash_table_new (g_direct_hash, g_direct_equal);
+	doc_int_to_pointer = g_hash_table_new (g_direct_hash, g_direct_equal);
+	win_pointer_to_int = g_hash_table_new (g_direct_hash, g_direct_equal);
+	win_int_to_pointer = g_hash_table_new (g_direct_hash, g_direct_equal);
+
 	msgbox_create ();
 	data = g_malloc0 (sizeof (gE_data));
 	window_list = NULL;
