@@ -23,11 +23,6 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#define PLUGIN_TEST 1
-#if PLUGIN_TEST
-#include "plugin.h"
-#endif
-
 #define STRING_LENGTH_MAX	256
 #define GEDIT_ID	"gEdit 0.4.5"
 
@@ -40,7 +35,8 @@ typedef struct _gE_search {
 	GtkWidget *start_at_beginning;
 	GtkWidget *case_sensitive;
 	GtkWidget *search_entry;
-	gint replace, again, line;
+	gint       line;
+	gboolean   replace, again;
 	GtkWidget *replace_box;
 	GtkWidget *replace_entry;
 	GtkWidget *prompt_before_replacing;
@@ -50,7 +46,6 @@ typedef struct _gE_search {
 
 typedef struct _gE_window {
 	GtkWidget *window;
-	GtkWidget *text;
 	GtkWidget *statusbox;
 	GtkWidget *statusbar;
 	GtkWidget *menubar;
@@ -63,26 +58,31 @@ typedef struct _gE_window {
 	GtkWidget *line_label, *col_label;
 	GtkWidget *files_list_window;
 	GtkWidget *files_list_window_data;
+	GtkWidget *files_list_window_toolbar;
 #ifdef GTK_HAVE_FEATURES_1_1_0
 	GtkAccelGroup *accel;
 #else
 	GtkAcceleratorTable *accel;
 #endif
 	GList *documents;
+	GtkWidget *popup;
 	gE_search *search;
 	int num_recent; /* Number of recently accessed documents in the 
 	                         Recent Documents menu */
 #ifdef WITHOUT_GNOME
+	GtkWidget *menubar_handle;	/* holds the menubar */
 	gboolean auto_indent;
 	gboolean show_tabs;
 	gboolean show_status;
-	gint have_toolbar;
-	gint have_tb_pix;
-	gint have_tb_text;
+	gboolean have_toolbar;
+	gboolean have_tb_pix;
+	gboolean have_tb_text;
+	gboolean show_tooltips;
 #else
 	gint auto_indent;
 	gint show_tabs;
 	gint show_status;
+	gint show_tooltips;
 	gint have_toolbar;
 	gint have_tb_pix;
 	gint have_tb_text;
@@ -90,9 +90,6 @@ typedef struct _gE_window {
 	gchar *print_cmd;
 	GtkPositionType tab_pos;
 
-#if PLUGIN_TEST
-	plugin *hello;
-#endif
 } gE_window;
 
 typedef struct _gE_document {
@@ -104,23 +101,16 @@ typedef struct _gE_document {
 	gint changed;
 	gint word_wrap;
 	struct stat *sb;
+#ifndef WITHOUT_GNOME
+	GtkWidget *scrollball;
+#endif
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	gint split;
+	GtkWidget *split_screen;
+	GtkWidget *flag;
+#endif
 } gE_document;
 
-typedef struct _gE_prefs {
-	GtkWidget *window;
-	GtkWidget *button;
-	GtkWidget *label;
-	GtkWidget *tfont;
-	GtkWidget *abox;
-	GtkWidget *bbox;
-	GtkWidget *separator;
-	GtkWidget *wrap, *synhi, *indent;
-	GtkWidget *tslant;
-	GtkWidget *tweight;
-	GtkWidget *tsize;
-	GtkWidget *pcmd;
-} gE_prefs;
-
 typedef struct _gE_data {
 	gE_window *window;
 	gE_document *document;
@@ -129,6 +119,20 @@ typedef struct _gE_data {
 	gboolean flag;	/* general purpose flag to indicate if action completed */
 } gE_data;
 
+typedef struct _gE_function {
+	gchar *name;
+	gchar *tooltip_text;
+	#ifdef WITHOUT_GNOME
+	gchar **icon;
+	#else
+	gchar *icon;
+	#endif
+	GtkSignalFunc callback;
+} gE_function;
+
+#ifdef WITHOUT_GNOME
+#define N_(String) (String)	/* To avoid duplication of code when adding gnome internationalization. */
+#endif
 
 extern GList *window_list;
 
