@@ -15,7 +15,6 @@ GtkWidget *dwin = NULL;
 static GtkWidget *nb;
 
 static GtkWidget *icl = NULL;
-static GtkWidget *ils [NUM_INFO];
 
 static GtkWidget *gswin = NULL;
 static Graph *gg;
@@ -35,7 +34,7 @@ static int  delete_event_handler (GtkWidget *widget, gpointer gp);
 void
 procview_details (gint pid)
 {
-	GtkWidget *vb, *hb;
+	GtkWidget *vb;
 	gchar *title;
 	gchar *form;
 
@@ -256,7 +255,7 @@ get_map_rows (pid_t pid, ProcMapRow **rs)
 				     "%08lx-%08lx %4c\n %08lx "
 				     "%02hx:%02hx %ld",
 				     &row->VMstart, &row->VMend,
-				     &row->flags, &row->VMoffset,
+				     row->flags, &row->VMoffset,
 				     &row->dev_major, &row->dev_minor,
 				     &row->inode);
 
@@ -267,7 +266,7 @@ get_map_rows (pid_t pid, ProcMapRow **rs)
 
 			if (fn [0] != '\n' && fn [0] != EOF) {
 
-				fscanf (maps, "%*[ ]%[^\n]\n", &fn);
+				fscanf (maps, "%*[ ]%[^\n]\n", fn);
 				row->filename = g_strdup (fn);
 
 			} else row->filename = NULL;
@@ -461,7 +460,7 @@ mem_graph_data_fn (GraphCmd cmd, gpointer data)
 		} else
 			fname = "";
 
-		sprintf (buf, "(%5s)\t: %8Ldk  %s",
+		sprintf (buf, "(%5s)\t: %8ldk  %s",
 			 mem_seg (rs),
 			 ((*rs)->VMend - (*rs)->VMstart) >> 10,
 			 fname);
