@@ -4,8 +4,6 @@
 
 #include <gnome.h>
 
-#define GNOME_PAD 6
-
 /* GtkWidget is the storage type for widgets */
 extern GtkWidget *window;
 extern GtkWidget *notebook;
@@ -24,10 +22,11 @@ extern GtkWidget *notebook;
 					->children, GTOP_TBAR_ ## x))->data)
 
 #define GTOP_MENU_VIEW           1
-#define GTOP_MENU_SYSTEM         2
-#define GTOP_MENU_HELP           3
+#define GTOP_MENU_MEMUSAGE       2
+#define GTOP_MENU_SYSTEM         3
+#define GTOP_MENU_HELP           4
 
-#define GTOP_MENU_HIDE_BEGIN     GTOP_MENU_SYSTEM
+#define GTOP_MENU_HIDE_BEGIN     GTOP_MENU_MEMUSAGE
 #define GTOP_MENU_HIDE_END       GTOP_MENU_SYSTEM
 
 #define GTOP_TBAR_RUN            0
@@ -42,6 +41,7 @@ extern char *tb_timer_xpm [];
 extern char *tb_timer_stopped_xpm [];
 
 extern GnomeUIInfo tbar [];
+extern void (*gtop_time_cb)(GtkWidget *w, gpointer gp);
 
 /* enums */
 
@@ -53,6 +53,7 @@ enum _gtop_pages {
 enum _GTopPageSignal {
 	GTOP_PAGE_LEAVE,
 	GTOP_PAGE_ENTER,
+	GTOP_PAGE_CFG_READ,
 	GTOP_PAGE_CFG_SAVE,
 };
 
@@ -65,4 +66,6 @@ typedef enum _GTopPages      GTopPages;
 void gnome_app_menu_traverse (void (*fn) (GtkWidget *),
 			      GnomeApp *app, gint first, gint last);
 
+extern gint tb_ss;
+
 #endif
