@@ -33,6 +33,9 @@
 #endif /* not DEBUG */
 
 
+char *first_proj_title = NULL;
+
+
 
 project *project_new(void)
 {
@@ -116,6 +119,8 @@ void project_set_desc(project *proj, char *d)
 		return;
 	}
 	proj->desc = g_strdup(d);
+	if (proj->row != -1)
+		clist_update_desc(proj);
 }
 
 
@@ -271,8 +276,6 @@ project_list_load_old(char *fname)
 	if (NULL == (f = fopen(fname, "rt"))) {
 #ifdef ENOENT
                 if (errno == ENOENT) return 0;
-#else
-#warning ENOENT not defined?
 #endif
 		g_warning("could not open %s\n", fname);
 		return 0;
@@ -417,6 +420,9 @@ project_list_load(char *fname)
         if (got_default) {
                 return project_list_load_old(fname);
         }
+	if ((cur_proj) && (cur_proj->title) && (!first_proj_title)) {
+		first_proj_title = g_strdup(cur_proj->title);
+	}
         project_list_destroy();
         _n = config_show_tb_new;
         _f = config_show_tb_file;
@@ -427,6 +433,11 @@ project_list_load(char *fname)
         _h = config_show_tb_help;
         _e = config_show_tb_exit;
         last_timer = atol(gnome_config_get_string(GTT"Misc/LastTimer=-1"));
+	if (gnome_config_get_int(GTT"Misc/TimerRunning=1")) {
+		start_timer();
+	} else {
+		stop_timer();
+	}
         config_show_secs = gnome_config_get_bool(GTT"Display/ShowSecs=false");
         config_show_clist_titles = gnome_config_get_bool(GTT"Display/ShowTableHeader=false");
         config_show_tb_icons = gnome_config_get_bool(GTT"Toolbar/ShowIcons=true");
@@ -446,12 +457,28 @@ project_list_load(char *fname)
         config_logfile_use = gnome_config_get_bool(GTT"LogFile/Use=false");
         config_logfile_name = gnome_config_get_string(GTT"LogFile/Filename");
         config_logfile_min_secs = gnome_config_get_int(GTT"LogFile/MinSecs");
+	for (i = 0; i < GTK_CLIST(glist)->columns; i++) {
+		sprintf(s, GTT"CList/ColumnWidth%d=0", i);
+		num = gnome_config_get_int(s);
+		if (num) {
+			clist_header_width_set = 1;
+			gtk_clist_set_column_width(GTK_CLIST(glist),
+						   i, num);
+		}
+	}
         num = gnome_config_get_int(GTT"Misc/NumProjects=0");
         for (i = 0; i < num; i++) {
                 proj = project_new();
                 project_list_add(proj);
                 sprintf(s, GTT"Project%d/Title", i);
                 project_set_title(proj, gnome_config_get_string(s));
+		if ((proj->title) && (first_proj_title)) {
+			if (0 == strcmp(proj->title, first_proj_title)) {
+				cur_proj_set(proj);
+				g_free(first_proj_title);
+				first_proj_title = NULL;
+			}
+		}
                 sprintf(s, GTT"Project%d/Desc", i);
                 project_set_desc(proj, gnome_config_get_string(s));
                 sprintf(s, GTT"Project%d/SecsEver=0", i);
@@ -459,6 +486,8 @@ project_list_load(char *fname)
                 sprintf(s, GTT"Project%d/SecsDay=0", i);
                 proj->day_secs = gnome_config_get_int(s);
         }
+	g_free(first_proj_title);
+	first_proj_title = NULL;
         update_status_bar();
         if ((_n != config_show_tb_new) ||
             (_f != config_show_tb_file) ||
@@ -485,6 +514,7 @@ project_list_save(char *fname)
         old_num = gnome_config_get_int(GTT"Misc/NumProjects=0");
         sprintf(s, "%ld", last_timer);
         gnome_config_set_string(GTT"Misc/LastTimer", s);
+        gnome_config_set_int(GTT"Misc/TimerRunning", (main_timer != 0));
         gnome_config_set_bool(GTT"Display/ShowSecs", config_show_secs);
         gnome_config_set_bool(GTT"Display/ShowTableHeader", config_show_clist_titles);
         gnome_config_set_bool(GTT"Toolbar/ShowIcons", config_show_tb_icons);
@@ -513,6 +543,10 @@ project_list_save(char *fname)
         else
                 gnome_config_clean_key(GTT"LogFile/Filename");
         gnome_config_set_int(GTT"LogFile/MinSecs", config_logfile_min_secs);
+	for (i = 0; i < GTK_CLIST(glist)->columns; i++) {
+		sprintf(s, GTT"CList/ColumnWidth%d", i);
+		gnome_config_set_int(s, GTK_CLIST(glist)->column[i].width);
+	}
         i = 0;
         for (pl = plist; pl; pl = pl->next) {
                 if (!pl->proj) continue;
@@ -564,6 +598,25 @@ char *project_get_timestr(project *proj, int show_secs)
 	return s;
 }
 
+char *project_get_total_timestr(project *proj, int show_secs)
+{
+	static char s[20];
+	time_t t;
+
+	if (proj == NULL) {
+		return NULL;
+	} else {
+		t = proj->secs;
+	}
+	if (show_secs)
+		sprintf(s, "%02d:%02d:%02d", (int)(t / 3600),
+			(int)((t % 3600) / 60), (int)(t % 60));
+	else
+		sprintf(s, "%02d:%02d", (int)(t / 3600),
+			(int)((t % 3600) / 60));
+	return s;
+}
+
 
 
 static void
@@ -600,6 +653,14 @@ cmp_time(const void *aa, const void *bb)
         return (int)(b->proj->day_secs - a->proj->day_secs);
 }
 
+static int
+cmp_total_time(const void *aa, const void *bb)
+{
+	project_list *a = *(project_list **)aa;
+	project_list *b = *(project_list **)bb;
+	return (int)(b->proj->secs - a->proj->secs);
+}
+
 
 
 static int
@@ -610,6 +671,13 @@ cmp_title(const void *aa, const void *bb)
         return strcmp(a->proj->title, b->proj->title);
 }
 
+static int
+cmp_desc(const void *aa, const void *bb)
+{
+	project_list *a = *(project_list **)aa;
+	project_list *b = *(project_list **)bb;
+	return strcmp(a->proj->desc, b->proj->desc);
+}
 
 
 void
@@ -618,10 +686,21 @@ project_list_sort_time(void)
         project_list_sort(cmp_time);
 }
 
-
+void
+project_list_sort_total_time(void)
+{
+	project_list_sort(cmp_total_time);
+}
 
 void
 project_list_sort_title(void)
 {
         project_list_sort(cmp_title);
 }
+
+void
+project_list_sort_desc(void)
+{
+	project_list_sort(cmp_desc);
+}
+
